aboutsummaryrefslogtreecommitdiff
path: root/Minecraft.Client/BoatRenderer.cpp
diff options
context:
space:
mode:
authorvoid_17 <heroerror3@gmail.com>2026-03-02 15:58:20 +0700
committervoid_17 <heroerror3@gmail.com>2026-03-02 15:58:20 +0700
commit7074f35e4ba831e358117842b99ee35b87f85ae5 (patch)
tree7d440d23473196af3056bf2ff4c59d9e740a06f5 /Minecraft.Client/BoatRenderer.cpp
parentd63f79325f85e014361eb8cf1e41eaebedb1ae71 (diff)
shared_ptr -> std::shared_ptr
This is one of the first commits in a plan to remove all `using namespace std;` lines in the entire codebase as it is considered anti-pattern today.
Diffstat (limited to 'Minecraft.Client/BoatRenderer.cpp')
-rw-r--r--Minecraft.Client/BoatRenderer.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/Minecraft.Client/BoatRenderer.cpp b/Minecraft.Client/BoatRenderer.cpp
index f1367ae4..33ffc322 100644
--- a/Minecraft.Client/BoatRenderer.cpp
+++ b/Minecraft.Client/BoatRenderer.cpp
@@ -10,11 +10,11 @@ BoatRenderer::BoatRenderer() : EntityRenderer()
model = new BoatModel();
}
-void BoatRenderer::render(shared_ptr<Entity> _boat, double x, double y, double z, float rot, float a)
+void BoatRenderer::render(std::shared_ptr<Entity> _boat, double x, double y, double z, float rot, float a)
{
// 4J - original version used generics and thus had an input parameter of type Boat rather than shared_ptr<Entity> we have here -
// do some casting around instead
- shared_ptr<Boat> boat = dynamic_pointer_cast<Boat>(_boat);
+ std::shared_ptr<Boat> boat = dynamic_pointer_cast<Boat>(_boat);
glPushMatrix();
@@ -10,11 +10,11 @@ BoatRenderer::BoatRenderer() : EntityRenderer()
{
- // 4J - original version used generics and thus had an input parameter of type Boat rather than shared_ptr<Entity> we have here -
+ // 4J - original version used generics and thus had an input parameter of type Boat rather than std::shared_ptr<Entity> we have here -
// do some casting around instead